@@ -16,7 +16,7 @@ from django.apps import apps
 # from importlib import import_module
 # from importlib.util import find_spec as importlib_find
 from django.db import DEFAULT_DB_ALIAS, connections, router
-from utils.comm.commapi import datetime_to_str
+from .commapi import datetime_to_str
 from django.conf import settings
 
 
